==> flutter_mylibrary-0.0.13.tar.gz: lib/base/smartrefresh_bloc.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/http_error.dart';
import 'bloc_provider.dart.dart';



abstract class SmartRefreshBlocBase extends PullToRefreshBloc {

  bool requestSuccess = false;

  @override
  void dispose() {
    // TODO: implement dispose
  }


  @override
  void initState() {
    eventBus.on().listen((event) {
      if(event is HttpError){
        requestSuccess = false;
      }else{
        requestSuccess = true;
      }
    });
  }


  /// 添加空布局
  Widget buildEmptyWidget(String message, {Widget emptyWidget}){
    return emptyWidget == null? Container(
      alignment: Alignment.center,
      child: Text(
          message
      ),
    ) : emptyWidget;
  }

  Widget buildFirstRefreshWidget(){
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        new CircularProgressIndicator(),
        Gaps.vGap10,
        new Text(
          '加载中',
          style: TextStyle(color: mainTextColor),
        )
      ],
    );
  }


  ///自定义头部
  Header headerCreate() {
    GlobalEasyRefreshLocalizations _localizations = GlobalEasyRefreshLocalizations();
    return ClassicalHeader(
      refreshText: _localizations.pullToRefresh,
      refreshReadyText: _localizations.pullToRefresh,
      refreshingText: _localizations.refreshing,
      refreshedText: _localizations.refreshed,
      infoText: _localizations.updateAt,
      bgColor: Colors.transparent,
      textColor: Colors.black87,
      infoColor: Colors.black54,
      showInfo: true,
      enableHapticFeedback: true
    );
  }

  ///自定义脚部
  Footer footerCreate() {
    GlobalEasyRefreshLocalizations _localizations = GlobalEasyRefreshLocalizations();
    return ClassicalFooter(
      loadText: _localizations.pushToLoad,
      loadReadyText: _localizations.pushToLoad,
      loadingText: _localizations.loading,
      noMoreText: _localizations.noMore,
      infoText: _localizations.updateAt,
      bgColor: Colors.transparent,
      textColor: Colors.black87,
      infoColor: Colors.black54,
      showInfo: true,
    );
  }



  EasyRefresh getEasyRefresh(Widget widget,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, Widget firstRefreshWidget, bool openLoadMore = true}){
    return EasyRefresh(
      header: headerCreate(),
      footer: footerCreate(),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      child: widget,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
          easyRefreshController.finishRefresh();
          emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad();
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,
    );

  }



  EasyRefresh getEasyRefreshCustom(List<Widget> slivers,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, Widget firstRefreshWidget, bool openLoadMore = true}){
    return EasyRefresh.custom(
      header: headerCreate(),
      footer: footerCreate(),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      slivers: slivers,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
            easyRefreshController.finishRefresh();
            emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad);
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,

    );
  }




}


///下拉刷新Bloc
abstract class PullToRefreshBloc extends BlocBase {
  ///加载数据
  Future getData({data});

  ///刷新
  Future onRefresh({data});

  ///更多
  Future onLoadMore({data});
}

==> flutter_mylibrary-0.0.18.tar.gz: lib/base/smartrefresh_bloc.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/http_error.dart';
import 'bloc_provider.dart.dart';



abstract class SmartRefreshBlocBase extends PullToRefreshBloc {

  bool requestSuccess = false;

  @override
  void dispose() {
    // TODO: implement dispose
  }


  @override
  void initState() {
    eventBus.on().listen((event) {
      if(event is HttpError){
        requestSuccess = false;
      }else{
        requestSuccess = true;
      }
    });
  }


  /// 添加空布局
  Widget buildEmptyWidget(String message, {Widget emptyWidget}){
    return emptyWidget == null? Container(
      alignment: Alignment.center,
      child: Text(
          message
      ),
    ) : emptyWidget;
  }

  Widget buildFirstRefreshWidget(){
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        new CircularProgressIndicator(),
        Gaps.vGap10,
        new Text(
          '加载中',
          style: TextStyle(color: mainTextColor),
        )
      ],
    );
  }


  ///自定义头部
  Header headerCreate() {
    GlobalEasyRefreshLocalizations _localizations = GlobalEasyRefreshLocalizations();
    return ClassicalHeader(
      refreshText: _localizations.pullToRefresh,
      refreshReadyText: _localizations.pullToRefresh,
      refreshingText: _localizations.refreshing,
      refreshedText: _localizations.refreshed,
      infoText: _localizations.updateAt,
      bgColor: Colors.transparent,
      textColor: Colors.black87,
      infoColor: Colors.black54,
      showInfo: true,
      enableHapticFeedback: true
    );
  }

  ///自定义脚部
  Footer footerCreate() {
    GlobalEasyRefreshLocalizations _localizations = GlobalEasyRefreshLocalizations();
    return ClassicalFooter(
      loadText: _localizations.pushToLoad,
      loadReadyText: _localizations.pushToLoad,
      loadingText: _localizations.loading,
      noMoreText: _localizations.noMore,
      infoText: _localizations.updateAt,
      bgColor: Colors.transparent,
      textColor: Colors.black87,
      infoColor: Colors.black54,
      showInfo: true,
    );
  }



  EasyRefresh getEasyRefresh(Widget widget,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, Widget firstRefreshWidget, bool openLoadMore = true}){
    return EasyRefresh(
      header: headerCreate(),
      footer: footerCreate(),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      child: widget,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
          easyRefreshController.finishRefresh();
          emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad(noMore: value, success: true);
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,
    );

  }



  EasyRefresh getEasyRefreshCustom(List<Widget> slivers,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, Widget firstRefreshWidget, bool openLoadMore = true}){
    return EasyRefresh.custom(
      header: headerCreate(),
      footer: footerCreate(),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      slivers: slivers,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
            easyRefreshController.finishRefresh();
            emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad(noMore: value, success: true);
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,

    );
  }




}


///下拉刷新Bloc
abstract class PullToRefreshBloc extends BlocBase {
  ///加载数据
  Future getData({data});

  ///刷新
  Future onRefresh({data});

  ///更多
  Future<bool> onLoadMore({data});
}
